pyroscopeextension

package module
v0.0.0-...-5667952 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 30, 2023 License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	ErrRequiresPositiveValue = errors.New("required positive value")
	ErrRequiresEndpoint      = errors.New("required endpoint")
	ErrRequiresValidProfile  = errors.New("required valid profile")
)
var (
	ErrAlreadyStarted = errors.New("already started")
	ErrNeverStarted   = errors.New("never started")
)

Functions

func NewFactory

func NewFactory() extension.Factory

Types

type Config

type Config struct {
	RuntimeMutexProfileFraction int `mapstructure:"runtime_mutex_fraction"`
	RuntimeBlockProfileFraction int `mapstructure:"runtime_block_fraction"`
	// Endpoint is server address to forward data to from the collector
	Endpoint string `mapstructure:"endpoint"`
	// AuthToken is used to provide authentication for the pyroscope server
	// Required if you're using pyroscope cloud.
	AuthToken configopaque.String `mapstructure:"auth_token"`
	// ApplicationName is used to set what application name should be assocated
	// with profiles being sent to pyroscope.
	ApplicationName string `mapstructure:"application_name"`
	// Tags are a set of attirbutes that help given context on how the
	// collector is configured and its environment.
	Tags map[string]string `mapstructure:"tags"`
	// Profiles are used to control what profiles are of interest
	// when sending data to pyroscope.
	//
	// Default is:
	// - cpu
	// - alloc_objects
	// - alloc_space
	// - inuse_objects
	// - inuse_space
	//
	// Additional profile types are:
	// - goroutines
	// - mutex_count
	// - mutex_duration
	// - block_count
	// - block_duration
	Profiles []pyroscope.ProfileType `mapstructure:"profiles"`
}

func (*Config) Unmarshal

func (c *Config) Unmarshal(parser *confmap.Conf) error

func (*Config) Validate

func (c *Config) Validate() (errs error)

Jump to