Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( ErrRequiresPositiveValue = errors.New("required positive value") ErrRequiresEndpoint = errors.New("required endpoint") ErrRequiresValidProfile = errors.New("required valid profile") )
var ( ErrAlreadyStarted = errors.New("already started") ErrNeverStarted = errors.New("never started") )
Functions ¶
func NewFactory ¶
Types ¶
type Config ¶
type Config struct {
RuntimeMutexProfileFraction int `mapstructure:"runtime_mutex_fraction"`
RuntimeBlockProfileFraction int `mapstructure:"runtime_block_fraction"`
// Endpoint is server address to forward data to from the collector
Endpoint string `mapstructure:"endpoint"`
// AuthToken is used to provide authentication for the pyroscope server
// Required if you're using pyroscope cloud.
AuthToken configopaque.String `mapstructure:"auth_token"`
// ApplicationName is used to set what application name should be assocated
// with profiles being sent to pyroscope.
ApplicationName string `mapstructure:"application_name"`
// Tags are a set of attirbutes that help given context on how the
// collector is configured and its environment.
Tags map[string]string `mapstructure:"tags"`
// Profiles are used to control what profiles are of interest
// when sending data to pyroscope.
//
// Default is:
// - cpu
// - alloc_objects
// - alloc_space
// - inuse_objects
// - inuse_space
//
// Additional profile types are:
// - goroutines
// - mutex_count
// - mutex_duration
// - block_count
// - block_duration
Profiles []pyroscope.ProfileType `mapstructure:"profiles"`
}
Click to show internal directories.
Click to hide internal directories.